@@ -10,7 +10,7 @@ GraphQL - Perl implementation of GraphQL
 
 =cut
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 =begin markdown
 
@@ -59,6 +59,8 @@ It now supports Promises, allowing asynchronous operation. See
 L<Mojolicious::Plugin::GraphQL> for an example of how to take advantage
 of this.
 
+As of 0.39, supports GraphQL subscriptions.
+
 See L<GraphQL::Type> for description of how to create GraphQL types.
 
 =head2 Introduction to GraphQL
@@ -186,6 +188,9 @@ L<https://perl.careers/>.
 Artur Khabibullin C<< <rtkh at cpan.org> >> contributed valuable ports
 of the JavaScript tests.
 
+The creation of the subscriptions functionality in this work has been
+sponsored by Sanctus.app: L<https://sanctus.app>.
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2017 Ed J.
