@@ -72,9 +72,9 @@ sub _build_to_doc {
     )
   } $self->_make_fieldtuples($self->fields);
   join '', map "$_\n",
-    ($self->description ? (map "# $_", split /\n/, $self->description) : ()),
+    $self->_description_doc_lines($self->description),
     "interface @{[$self->name]} {",
-      (map "  $_", @fieldlines),
+      (map length() ? "  $_" : "", @fieldlines),
     "}";
 }
 
