@@ -131,14 +131,8 @@ our $Int = GraphQL::Type::Scalar->new(
   description =>
     'The `Int` scalar type represents non-fractional signed whole numeric ' .
     'values. Int can represent values between -(2^31) and 2^31 - 1.',
-  serialize => sub { return undef if !defined $_[0]; Int32Signed->(@_); $_[0]+0 },
-  parse_value => sub {
-    DEBUG and _debug('Int.parse_value', @_, $JSON->encode({ intval => $_[0] }));
-    return undef if !defined $_[0];
-    Int32Signed->(@_);
-    DEBUG and _debug('Int.parse_value(after asserts)', @_, $JSON->encode({ intval => $_[0] }));
-    $_[0]+0
-  },
+  serialize => sub { defined $_[0] and !is_Int32Signed($_[0]) and die "Not an Int.\n"; $_[0]+0 },
+  parse_value => sub { defined $_[0] and !is_Int32Signed($_[0]) and die "Not an Int.\n"; $_[0]+0 },
 );
 
 =head2 $Float
@@ -151,8 +145,8 @@ our $Float = GraphQL::Type::Scalar->new(
     'The `Float` scalar type represents signed double-precision fractional ' .
     'values as specified by ' .
     '[IEEE 754](http://en.wikipedia.org/wiki/IEEE_floating_point).',
-  serialize => sub { return undef if !defined $_[0]; Num->(@_); $_[0]+0 },
-  parse_value => sub { return undef if !defined $_[0]; Num->(@_); $_[0]+0 },
+  serialize => sub { defined $_[0] and !is_Num($_[0]) and die "Not a Float.\n"; $_[0]+0 },
+  parse_value => sub { defined $_[0] and !is_Num($_[0]) and die "Not a Float.\n"; $_[0]+0 },
 );
 
 =head2 $String
@@ -177,8 +171,8 @@ our $Boolean = GraphQL::Type::Scalar->new(
   name => 'Boolean',
   description =>
     'The `Boolean` scalar type represents `true` or `false`.',
-  serialize => sub { return undef if !defined $_[0]; Bool->(@_); $_[0] ? JSON->true : JSON->false },
-  parse_value => sub { return undef if !defined $_[0]; is_bool(@_); $_[0]+0 },
+  serialize => sub { defined $_[0] and !is_Bool($_[0]) and die "Not a Boolean.\n"; $_[0] ? JSON->true : JSON->false },
+  parse_value => sub { defined $_[0] and !is_bool($_[0]) and die "Not a Boolean.\n"; $_[0]+0 },
 );
 
 =head2 $ID
